# -*- coding: utf-8 -*-
__author__ = 'zhangjinjie'

import unittest
from test_location_api import TestLocationApi
from test_place_api import TestPlaceApi
from test_scheduler import TestRoundRobinScheduler
from test_transform_api import TestTransformApi
from test_map_api import TestMapApi

if __name__ == '__main__':
    unittest.main()

